point.df: Point-centered quarter dataset

point.dfR Documentation

Point-centered quarter dataset

Description

A dataset containing tree measurements collected using the point-centered quarter method at 25 sampling points in a forest fragment located at the campus of the University of Sao Paulo, Ribeirao Preto, Brazil. At each point, the nearest tree in each of the four quadrants was sampled, totaling 100 individuals.

Usage

data(point.df)

Format

A data frame with 100 rows and 6 variables:

Point

Sampling point identifier (1–25).

Family

Botanical family of the tree.

Species

Scientific name of the species.

Distance

Distance from the point to the tree (m).

CBH

Circumference at breast height (cm).

h

Total height of the tree (m).


PhytoIn documentation built on Nov. 5, 2025, 5:47 p.m.