quadrat.df: Forest inventory dataset from 25 quadrats

quadrat.dfR Documentation

Forest inventory dataset from 25 quadrats

Description

A dataset containing tree measurements from 25 quadrats (5 Ă— 5 m each) sampled in a forest fragment located at the campus of the University of Sao Paulo, Ribeirao Preto, Brazil.

Usage

data(quadrat.df)

Format

A data frame with 171 rows and 5 variables:

Plot

Quadrat identifier (e.g., X2Y3).

Family

Botanical family of the tree.

Species

Scientific name of the species.

CBH

Circumference at breast height (cm).

h

Total height of the tree (m).


PhytoIn documentation built on Nov. 5, 2025, 5:47 p.m.