quadrat2_plot.df: Quadrat dataset with coordinates for basal area plotting

quadrat2_plot.dfR Documentation

Quadrat dataset with coordinates for basal area plotting

Description

A dataset containing tree measurements from 25 quadrats (5 Ă— 5 m each) sampled in a forest fragment located at the campus of the University of Sao Paulo, Ribeirao Preto, Brazil. This dataset is organized to demonstrate the use of the function BAplot() for visualizing basal areas. In addition to tree measurements, it provides the spatial coordinates of the lower-left corner of each quadrat.

Usage

data(quadrat2_plot.df)

Format

A data frame with 219 rows and 6 variables:

Plot

Quadrat identifier (e.g., X1Y1).

CBH

Circumference at breast height (cm).

h

Total height of the tree (m).

Species

Scientific name of the species.

x

X coordinate (m) of the lower-left corner of the quadrat.

y

Y coordinate (m) of the lower-left corner of the quadrat.


PhytoIn documentation built on Nov. 5, 2025, 5:47 p.m.