Learn R Programming

PhytoIn (version 0.2.0)

quadrat2_tree.df: Quadrat dataset with simulated individual tree coordinates

Description

A dataset containing tree measurements from 25 quadrats (5 × 5 m each) sampled in a forest fragment located at the campus of the University of Sao Paulo, Ribeirao Preto, Brazil. This dataset corresponds to the same trees as in quadrat2_plot.df, but includes simulated coordinates (in meters) for each individual tree inside the quadrats. It is organized to demonstrate the use of the function BAplot() with the argument ind.coord = TRUE.

Usage

data(quadrat2_tree.df)

Arguments

Format

A data frame with 219 rows and 7 variables:

Plot

Quadrat identifier (e.g., X1Y1).

CBH

Circumference at breast height (cm).

h

Total height of the tree (m).

Species

Scientific name of the species.

x

Simulated X coordinate (m) of the tree inside the quadrat.

y

Simulated Y coordinate (m) of the tree inside the quadrat.