Learn R Programming

PhytoIn (version 0.2.0)

quadrat3_rect.df: Rectangular quadrat dataset

Description

A dataset containing tree measurements from 25 rectangular quadrats (20 × 10 m each) sampled in a seasonal semideciduous forest fragment in the State of Sao Paulo, Brazil. The dataset includes total height and commercial bole height of trees, along with the spatial coordinates of the lower-left corner of each quadrat. It is organized to demonstrate the use of the function BAplot() with rectangular quadrats.

Usage

data(quadrat3_rect.df)

Arguments

Format

A data frame with 497 rows and 8 variables:

Plot

Quadrat identifier.

x

X coordinate (m) of the lower-left corner of the quadrat.

y

Y coordinate (m) of the lower-left corner of the quadrat.

Species

Scientific name of the species.

Family

Botanical family of the tree.

DBH

Diameter at breast height (cm).

h

Total height of the tree (m).

hcom

Commercial bole height of the tree (m).