| plot.param | R Documentation |
Produce a stacked bar chart of relative dominance (RDo), relative frequency (RFr),
and relative density (RDe) for each taxon contained in a param object returned
by phytoparam. Taxa are ordered by the Importance Value (IV).
## S3 method for class 'param'
plot(x, theme = "theme_classic", ...)
x |
An object of class |
theme |
A ggplot2 theme to apply. Either a character string naming a theme
constructor in ggplot2 (e.g., |
... |
Ignored. |
The function reshapes the taxon-level table to long format and draws a
horizontal stacked bar chart (RDo, RFr, RDe) with taxa ordered by increasing IV.
A ggplot object.
phytoparam, summary.param, and ggplot2.
res <- phytoparam(x = quadrat.df, measure.label = "CBH", taxon = "Species",
dead = "Morta", family = "Family", circumference = TRUE,
su = "Plot", height = TRUE, su.size = 25)
plot(res) # default theme (theme_classic)
plot(res, theme = "theme_light") # theme by name
plot(res, theme = ggplot2::theme_minimal()) # theme object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.