| point.df | R Documentation |
A dataset containing tree measurements collected using the point-centered quarter method at 25 sampling points in a forest fragment located at the campus of the University of Sao Paulo, Ribeirao Preto, Brazil. At each point, the nearest tree in each of the four quadrants was sampled, totaling 100 individuals.
data(point.df)
A data frame with 100 rows and 6 variables:
Sampling point identifier (1–25).
Botanical family of the tree.
Scientific name of the species.
Distance from the point to the tree (m).
Circumference at breast height (cm).
Total height of the tree (m).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.