| quadrat.df | R Documentation |
A dataset containing tree measurements from 25 quadrats (5 Ă— 5 m each) sampled in a forest fragment located at the campus of the University of Sao Paulo, Ribeirao Preto, Brazil.
data(quadrat.df)
A data frame with 171 rows and 5 variables:
Quadrat identifier (e.g., X2Y3).
Botanical family of the tree.
Scientific name of the species.
Circumference at breast height (cm).
Total height of the tree (m).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.