| quadrat2_plot.df | R Documentation |
A dataset containing tree measurements from 25 quadrats (5 Ă— 5 m each)
sampled in a forest fragment located at the campus of the University of Sao Paulo,
Ribeirao Preto, Brazil. This dataset is organized to demonstrate the use of the
function BAplot() for visualizing basal areas. In addition to tree measurements,
it provides the spatial coordinates of the lower-left corner of each quadrat.
data(quadrat2_plot.df)
A data frame with 219 rows and 6 variables:
Quadrat identifier (e.g., X1Y1).
Circumference at breast height (cm).
Total height of the tree (m).
Scientific name of the species.
X coordinate (m) of the lower-left corner of the quadrat.
Y coordinate (m) of the lower-left corner of the quadrat.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.