A dataset containing tree measurements from 25 quadrats (5 × 5 m each)
sampled in a forest fragment located at the campus of the University of Sao Paulo,
Ribeirao Preto, Brazil. This dataset corresponds to the same trees as in
quadrat2_plot.df, but includes simulated coordinates (in meters) for
each individual tree inside the quadrats. It is organized to demonstrate the
use of the function BAplot() with the argument ind.coord = TRUE.
data(quadrat2_tree.df)A data frame with 219 rows and 7 variables:
Quadrat identifier (e.g., X1Y1).
Circumference at breast height (cm).
Total height of the tree (m).
Scientific name of the species.
Simulated X coordinate (m) of the tree inside the quadrat.
Simulated Y coordinate (m) of the tree inside the quadrat.