| summary.param | R Documentation |
Display a concise summary of the global parameters computed by phytoparam.
If family-level outputs are present (i.e., the string "N. of families" occurs
in the first column of object$global), the first seven rows are shown;
otherwise, the first six rows are shown.
## S3 method for class 'param'
summary(object, ...)
object |
An object of class |
... |
Ignored. |
Row names of object$global are removed before printing.
The function is intended for quick inspection of the main global metrics.
Used mainly for its side effect of printing to the console.
Invisibly returns the displayed data.frame.
PhytoIn (phytoparam, plot.param.
res <- phytoparam(x = quadrat.df, measure.label = "CBH",
taxon = "Species", family = "Family",
su = "Plot", su.size = 25)
summary(res) # calls summary.param (S3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.