Learn R Programming

PhytoIn (version 0.2.0)

summary.param: Summarize global phytosociological parameters

Description

Display a concise summary of the global parameters computed by phytoparam. If family-level outputs are present (i.e., the string "N. of families" occurs in the first column of object$global), the first seven rows are shown; otherwise, the first six rows are shown.

Usage

# S3 method for param
summary(object, ...)

Value

Used mainly for its side effect of printing to the console. Invisibly returns the displayed data.frame.

Arguments

object

An object of class param returned by phytoparam.

...

Ignored.

Details

Row names of object$global are removed before printing. The function is intended for quick inspection of the main global metrics.

See Also

PhytoIn (phytoparam, plot.param.

Examples

Run this code
# \donttest{
res <- phytoparam(x = quadrat.df, measure.label = "CBH",
                  taxon = "Species", family = "Family",
                  su = "Plot", su.size = 25)
summary(res)  # calls summary.param (S3)
# }

Run the code above in your browser using DataLab